from collections import defaultdict

from typing import Optional
from pydantic import  BaseModel

from gtagger.config import get_config
from gtagger.file_explorer import FileExplorer

class DocumentAnalyzer(BaseModel):
    def __init__(self, documents: FileExplorer, config: Optional[dict] = None):
        self.documents = documents
        self.config = config or get_config()
        self._dir_content = defaultdict(lambda: {
            "type": None,
            "converted": False,
            "processed": False,
            "archived": False,
        }) 

    @property
    def dir_content(self):
        return self._dir_content

    def document_status(self):
        """Effettua l'attraversamento di un path.
        
        Ritorna un oggetto con lo stato di un documento in relazione ai
        files presenti che  hanno lo stesso path, ma differiscono nell'estensione
        """
        # {
        #     "path relativo a root dati completo senza estensione" : {
        #         "type": "pdf",
        #         "converted": True,
        #         "processed": False 
        #         "archived": False    
        #     }
        
        # }      
        
        for suffix, files in self.explorer.files.items():
            
            for path in files:
                base = str(path.relative_to(self.explorer.root).with_suffix(""))
                
                if suffix in self.config.extension:
                    self.dir_content[base]["type"] = suffix[1:]
                elif suffix == ".md":
                    self.dir_content[base]["converted"] = True
                elif suffix == ".json":
                    self.dir_content[base]["processed"] = True
                elif suffix == ".ok":
                    self.dir_content[base]["archived"] = True
        return self.dir_content