import logging
import json
log = logging.getLogger(__name__)
from gtagger.file_explorer import FileExplorer

# "_usage_data" : {
#    "input_tokens": 0,
#    "output_tokens": 0,
#    "total_tokens": 0,
# }

class TokenStatsCalculator:
    def __init__(self, explorer: FileExplorer):
        self.explorer = explorer
        self._fields = ("_usage_data", "_usage_filename")
        self._keys = ("input_tokens", "output_tokens", "total_tokens")
        self._estimated_tokens : int = 0
        # creo il dizionario che ospita le somme (come da struttura sopra)
        self._real_tokens = {field:
                             {key: 0 for key in self._keys} for field in self._fields}

    @property
    def estimated_tokens(self) -> float:
        return self._estimated_tokens

    @property
    def real_token_data(self) -> dict:
        return self._real_tokens

    @property
    def fields(self) -> tuple:
        return self._fields

    @property
    def keys(self) -> tuple:
        return self._keys


    def token_consumption(self):
        for file in self.explorer.files.get(".json", []):
            try:
                with open(file, 'r') as f:
                    data = json.load(f)
                    for field in self._fields:
                        usage = data.get(field)
                        if isinstance(usage, dict):
                            for key in self._keys:
                                if key in usage:
                                    self._real_tokens[field][key] += usage[key]
            except json.JSONDecodeError as e:
                raise ValueError(f"Errore {e} nel parsing del JSON: {file}")


    def token_estimation(self):
        tokens = 0

        for file in self.explorer.files.get(".md", []):
            with open(file, "r") as f:
                testo_da_elaborare = f.read()
                tokens += len(testo_da_elaborare.split())
        
        self._estimated_tokens = tokens / 4


    def get_estimated_tokens(self) -> float:
        return self._estimated_tokens


    def get_real_token_data(self) -> dict:
        return self._real_tokens


    def get_fields(self) -> tuple:
        return self._fields


    def get_keys(self) -> tuple:
        return self._keys